@@ -1,21 +1,30 @@
 // Fuzzy Hashing by Jesse Kornblum
 // Copyright (C) 2010 ManTech International Corporation
 //
-// $Id: main.c 97 2010-03-19 15:10:06Z jessekornblum $
+// $Id: main.c 118 2011-09-30 11:10:51Z jessekornblum $
 //
 // This program is licensed under version 2 of the GNU Public License.
 // See the file COPYING for details. 
 
-
 #include "ssdeep.h"
 
+#ifdef _WIN32 
+// This can't go in main.h or we get multiple definitions of it
+// Allows us to open standard input in binary mode by default 
+// See http://gnuwin32.sourceforge.net/compile.html for more 
+int _CRT_fmode = _O_BINARY;
+#endif
+
+
 static int initialize_state(state *s)
 {
   if (match_init(s))
     return TRUE;
 
-  s->first_file_processed = TRUE;
-  s->mode                 = mode_none;
+  s->mode                  = mode_none;
+  s->first_file_processed  = TRUE;
+  s->found_meaningful_file = FALSE;
+  s->processed_file        = FALSE;
 
   s->threshold = 0;
 
@@ -251,45 +260,58 @@ int main(int argc, char **argv)
   // or directory we're supposed to process. If there's nothing
   // specified, we should tackle standard input 
   if (optind == argc)
-    fatal_error("%s: No input files", __progname);
-
-  MD5DEEP_ALLOC(TCHAR,fn,PATH_MAX);
-  MD5DEEP_ALLOC(TCHAR,cwd,PATH_MAX);
-
-  cwd = _tgetcwd(cwd,PATH_MAX);
-  if (NULL == cwd)
-    fatal_error("%s: %s", __progname, strerror(errno));
-  
-  count = optind;
-  
-  // The signature comparsion mode needs to use the command line
-  // arguments and argument count. We don't do wildcard expansion
-  // on it on Win32 (i.e. where it matters). The setting of 'goal'
-  // to the original argc occured at the start of main(), so we just
-  // need to update it if we're *not* in signature compare mode.
-  if (!(s->mode & mode_sigcompare))
   {
-    goal = s->argc;
+    status = process_stdin(s);
   }
-
-  while (count < goal)
+  else
   {
-    if (MODE(mode_sigcompare))
-      match_load(s,argv[count]);
-    else if (MODE(mode_compare_unknown))
-      match_compare_unknown(s,argv[count]);
-    else
+    MD5DEEP_ALLOC(TCHAR,fn,PATH_MAX);
+    MD5DEEP_ALLOC(TCHAR,cwd,PATH_MAX);
+    
+    cwd = _tgetcwd(cwd,PATH_MAX);
+    if (NULL == cwd)
+      fatal_error("%s: %s", __progname, strerror(errno));
+  
+    count = optind;
+  
+    // The signature comparsion mode needs to use the command line
+    // arguments and argument count. We don't do wildcard expansion
+    // on it on Win32 (i.e. where it matters). The setting of 'goal'
+    // to the original argc occured at the start of main(), so we just
+    // need to update it if we're *not* in signature compare mode.
+    if (!(s->mode & mode_sigcompare))
     {
-      generate_filename(s,fn,cwd,s->argv[count]);
+      goal = s->argc;
+    }
+    
+    while (count < goal)
+    {
+      if (MODE(mode_sigcompare))
+	match_load(s,argv[count]);
+      else if (MODE(mode_compare_unknown))
+	match_compare_unknown(s,argv[count]);
+      else
+      {
+	generate_filename(s,fn,cwd,s->argv[count]);
 
 #ifdef _WIN32
-      status = process_win32(s,fn);
+	status = process_win32(s,fn);
 #else
-      status = process_normal(s,fn);
+	status = process_normal(s,fn);
 #endif
+      }
+      
+      ++count;
     }
 
-    ++count;
+    // If we processed files, but didn't find anything large enough
+    // to be meaningful, we should display a warning message to the user.
+    // This happens mostly when people are testing very small files
+    // e.g. $ echo "hello world" > foo && ssdeep foo
+    if ( ! s->found_meaningful_file && s->processed_file)
+    {
+      print_error(s,"%s: Did not process files large enough to produce meaningful results", __progname);
+    }
   }
 
 
