@@ -1,7 +1,7 @@
 // ssdeep
 // Copyright (C) 2010 ManTech International Corporation.
 //
-// $Id: main.h 104 2010-07-15 22:11:12Z jessekornblum $
+// $Id: main.h 118 2011-09-30 11:10:51Z jessekornblum $
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -112,6 +112,8 @@
 #define SSDEEPV1_1_HEADER        "ssdeep,1.1--blocksize:hash:hash,filename"
 #define OUTPUT_FILE_HEADER     SSDEEPV1_1_HEADER
 
+// We print a warning for files smaller than this size
+#define SSDEEP_MIN_FILE_SIZE   4096
 
 #define MD5DEEP_ALLOC(TYPE,VAR,SIZE)     \
 VAR = (TYPE *)malloc(sizeof(TYPE) * SIZE);  \
@@ -148,6 +150,8 @@ typedef struct {
   uint64_t  mode;
   lsh_list  *known_hashes;
   uint8_t   threshold;
+  int       found_meaningful_file;
+  int       processed_file;
   int       argc;
   TCHAR     **argv;
 } state;
@@ -220,12 +224,14 @@ int have_processed_dir(TCHAR *fn);
 
 int process_win32(state *s, TCHAR *fn);
 int process_normal(state *s, TCHAR *fn);
+int process_stdin(state *s);
 
 
 // *********************************************************************
 // Fuzzy Hashing Engine
 // *********************************************************************
 int hash_file(state *s, TCHAR *fn);
+void display_result(state *s, TCHAR * fn, char * sum);
 
 
 // *********************************************************************
