@@ -1,5 +1,5 @@
 
-/* $Id: ui.c 104 2010-07-15 22:11:12Z jessekornblum $ */
+/* $Id: ui.c 118 2011-09-30 11:10:51Z jessekornblum $ */
 
 #include "ssdeep.h"
 #include <stdarg.h>
@@ -27,10 +27,10 @@ void print_error(state *s, char *fmt, ...)
   va_list(ap);
   
   va_start(ap,fmt); 
-  vprintf(fmt,ap); 
+  vfprintf(stderr,fmt,ap); 
   va_end(ap); 
   
-  printf ("%s", NEWLINE);
+  fprintf (stderr,"%s", NEWLINE);
 
 }
 
